==> tty-client-L0.09.tar.gz: tty-client-L0.09/libraries/libcommon/kom-errno.c <==
/*
 * $Id: kom-errno.c,v 0.5 1993/01/16 23:14:39 ceder Exp $
 * Copyright (C) 1991  Lysator Academic Computer Association.
 *
 * This file is part of the LysKOM server.
 * 
 * LysKOM is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 1, or (at your option) 
 * any later version.
 * 
 * LysKOM is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with LysKOM; see the file COPYING.  If not, write to
 * Lysator, c/o ISY, Linkoping University, S-581 83 Linkoping, SWEDEN,
 * or the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
 * MA 02139, USA.
 *
 * Please mail bug reports to bug-lyskom@lysator.liu.se. 
 */
/*
 * kom_errno.c
 *
 * Created by ceder 1990-05-13
 *
 */


static char *rcsid = "$Id: kom-errno.c,v 0.5 1993/01/16 23:14:39 ceder Exp $";

#include <stdio.h>

#include <config.h>

#include <kom-errno.h>
#include "rcs.h"
USE(rcsid);


Kom_err	kom_errno = 0;

/* Additional information about the error */
u_long 	err_stat = 0;

/* Note that kom_errout is defined in config.h */

void
kom_perror(void)
{
    switch (kom_errno)
    {
    case  KOM_NO_ERROR:
	fprintf (kom_errout, "Why am I called? There was no error!\n");
	break;

    case KOM_NOT_IMPL:
	fprintf(kom_errout, "Not implemented yet\n");
	break;
	
    case KOM_PWD:
	fprintf(kom_errout, "Wrong/illegal password\n");
	break;
	
    case KOM_LOGIN:
	fprintf(kom_errout, "Not logged in.\n");
	break;
	
    case KOM_LOGIN_DISALLOWED:
	fprintf(kom_errout, "System is in 'singel-user mode'\n");
	break;
	
    case KOM_CONF_ZERO:
	fprintf(kom_errout, "Attempt to use conference number 0.\n");
	break;
	
    case KOM_UNDEF_CONF:
	fprintf(kom_errout, "Undefined or secret conference\n");
	break;
	
    case KOM_UNDEF_PERS:
	fprintf(kom_errout, "Undefined or secret person\n");
	break;
	
    case KOM_ACCESS:
	fprintf(kom_errout, "No 'read/write permission'\n");
	break;

    case KOM_SECRET_PUBLIC:
	fprintf(kom_errout, "Cannot be secret and !rd_prot\n");
	break;

    case KOM_LETTER_BOX:
	fprintf(kom_errout, "Cannot change letter_box flag\n");
	break;

    case KOM_PERM:
	fprintf(kom_errout, "No permission\n");
	break;
	
    case KOM_NOT_MEMBER:
	fprintf(kom_errout, "Not member in conf\n");
	break;

    case KOM_NO_SUCH_TEXT:
	fprintf(kom_errout, "No such global text as %ld or no access\n",
			    err_stat);
	break;
	
    case KOM_NO_SUCH_LOCAL_TEXT:
	fprintf(kom_errout, "No such local text as %ld\n", err_stat);
	break;

    case KOM_INDEX_OUT_OF_RANGE:
	fprintf(kom_errout, "Index out of range\n");
	break;
	
    case KOM_BAD_NAME:
	fprintf(kom_errout, "To short/long or contains illegal chars\n");
	break;
	
    case KOM_CONF_EXISTS:
	fprintf(kom_errout, "Already exists\n");
	break;
	
    case KOM_PERS_EXISTS:
	fprintf(kom_errout, "Already exists\n");
	break;
	
    case KOM_LDB_ERR:
	fprintf(kom_errout, "LDB_err\n");
	break;
	
    case KOM_ILL_MISC:
	fprintf(kom_errout, "Illegal misc field at %ld.\n", err_stat);
	break;
	
    case KOM_ILLEGAL_INFO_TYPE:
	fprintf(kom_errout, "Info_type parameter illegal. Client is buggy.\n");
	break;
	
    case KOM_ALREADY_RECIPIENT:
	fprintf(kom_errout, "Already recipient to this text.\n");
	break;

    case KOM_NOT_RECIPIENT:
	fprintf(kom_errout, "Not recipient.\n");
	break;
	
    case KOM_RECIPIENT_LIMIT:
	fprintf(kom_errout, "Too many recipients.\n");
	break;
	
    case KOM_COMM_LIMIT:
	fprintf(kom_errout, "Too many comments.\n");
	break;
	
    case KOM_FOOT_LIMIT:
	fprintf(kom_errout, "Too many footnotes.\n");
	break;
	
    case KOM_NOT_AUTHOR:
	fprintf(kom_errout, "Only the author may add footnotes.\n");
	break;

    case  KOM_OBSOLETE:
	fprintf (kom_errout, "Servern {r inte kompatibel med mig.\n");
	break;

    case  KOM_LONG_STR:
	fprintf (kom_errout, "F|r l}ng str{ng.\n");
	break;

    case  KOM_NO_CONNECT:
	fprintf (kom_errout, "Kan ej f} kontakt med servern.\n");
	break;

    case  KOM_OUT_OF_MEMORY:
	fprintf (kom_errout, "Dumma Emacs! Fattar du inte att du inte ska "
		 "bryta en\nrad inuti en str{ng bara f|r att man anv{nder "
		 "} och {???\n");
	break;

    case  KOM_SERVER_IS_CRAZY:
	fprintf (kom_errout, "Hmm, jag tror servern har b|rjat tala i "
		 "tungom}l...\n");
	break;

    case  KOM_CLIENT_IS_CRAZY:
	fprintf (kom_errout, "Hoppschan. Jag har vischt b|rjat schluddra.\n");
	break;
	
#ifndef COMPILE_CHECKS
    default:
	fprintf(kom_errout, "Unknown error %d\n", kom_errno);
	break;
#endif
    }
}

==> tty-client-L0.11.tar.gz: tty-client-L0.11/libraries/libcommon/kom-errno.c <==
/*
 * $Id: kom-errno.c,v 0.7 1993/10/10 12:02:49 ceder Exp $
 * Copyright (C) 1991  Lysator Academic Computer Association.
 *
 * This file is part of the LysKOM server.
 * 
 * LysKOM is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 1, or (at your option) 
 * any later version.
 * 
 * LysKOM is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with LysKOM; see the file COPYING.  If not, write to
 * Lysator, c/o ISY, Linkoping University, S-581 83 Linkoping, SWEDEN,
 * or the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
 * MA 02139, USA.
 *
 * Please mail bug reports to bug-lyskom@lysator.liu.se. 
 */
/*
 * kom_errno.c
 *
 * Created by ceder 1990-05-13
 *
 */


static char *rcsid = "$Id: kom-errno.c,v 0.7 1993/10/10 12:02:49 ceder Exp $";
#include "rcs.h"
USE(rcsid);

#include <stdio.h>

#include "kom-errno.h"
#include "config.h"

Kom_err	kom_errno = 0;

/* Additional information about the error */
unsigned long 	err_stat = 0;

/* Note that kom_errout is defined in config.h */

void
kom_perror(void)
{
    switch (kom_errno)
    {
    case  KOM_NO_ERROR:
	fprintf (kom_errout, "Why am I called? There was no error!\n");
	break;

    case KOM_NOT_IMPL:
	fprintf(kom_errout, "Not implemented yet\n");
	break;
	
    case KOM_PWD:
	fprintf(kom_errout, "Wrong/illegal password\n");
	break;
	
    case KOM_LOGIN:
	fprintf(kom_errout, "Not logged in.\n");
	break;
	
    case KOM_LOGIN_DISALLOWED:
	fprintf(kom_errout, "System is in 'singel-user mode'\n");
	break;
	
    case KOM_CONF_ZERO:
	fprintf(kom_errout, "Attempt to use conference number 0.\n");
	break;
	
    case KOM_UNDEF_CONF:
	fprintf(kom_errout, "Undefined or secret conference\n");
	break;
	
    case KOM_UNDEF_PERS:
	fprintf(kom_errout, "Undefined or secret person\n");
	break;
	
    case KOM_ACCESS:
	fprintf(kom_errout, "No 'read/write permission'\n");
	break;

    case KOM_SECRET_PUBLIC:
	fprintf(kom_errout, "Cannot be secret and !rd_prot\n");
	break;

    case KOM_LETTER_BOX:
	fprintf(kom_errout, "Cannot change letter_box flag\n");
	break;

    case KOM_PERM:
	fprintf(kom_errout, "No permission\n");
	break;
	
    case KOM_NOT_MEMBER:
	fprintf(kom_errout, "Not member in conf\n");
	break;

    case KOM_NO_SUCH_TEXT:
	fprintf(kom_errout, "No such global text as %ld or no access\n",
			    err_stat);
	break;
	
    case KOM_NO_SUCH_LOCAL_TEXT:
	fprintf(kom_errout, "No such local text as %ld\n", err_stat);
	break;

    case KOM_INDEX_OUT_OF_RANGE:
	fprintf(kom_errout, "Index out of range\n");
	break;
	
    case KOM_BAD_NAME:
	fprintf(kom_errout, "To short/long or contains illegal chars\n");
	break;
	
    case KOM_CONF_EXISTS:
	fprintf(kom_errout, "Already exists\n");
	break;
	
    case KOM_PERS_EXISTS:
	fprintf(kom_errout, "Already exists\n");
	break;
	
    case KOM_LDB_ERR:
	fprintf(kom_errout, "LDB_err\n");
	break;
	
    case KOM_ILL_MISC:
	fprintf(kom_errout, "Illegal misc field at %ld.\n", err_stat);
	break;
	
    case KOM_ILLEGAL_INFO_TYPE:
	fprintf(kom_errout, "Info_type parameter illegal. Client is buggy.\n");
	break;
	
    case KOM_ALREADY_RECIPIENT:
	fprintf(kom_errout, "Already recipient to this text.\n");
	break;

    case KOM_NOT_RECIPIENT:
	fprintf(kom_errout, "Not recipient.\n");
	break;
	
    case KOM_RECIPIENT_LIMIT:
	fprintf(kom_errout, "Too many recipients.\n");
	break;
	
    case KOM_COMM_LIMIT:
	fprintf(kom_errout, "Too many comments.\n");
	break;
	
    case KOM_FOOT_LIMIT:
	fprintf(kom_errout, "Too many footnotes.\n");
	break;
	
    case KOM_NOT_AUTHOR:
	fprintf(kom_errout, "Only the author may add footnotes.\n");
	break;

    case  KOM_OBSOLETE:
	fprintf (kom_errout, "Servern {r inte kompatibel med mig.\n");
	break;

    case  KOM_LONG_STR:
	fprintf (kom_errout, "F|r l}ng str{ng.\n");
	break;

    case  KOM_NO_CONNECT:
	fprintf (kom_errout, "Kan ej f} kontakt med servern.\n");
	break;

    case  KOM_OUT_OF_MEMORY:
	fprintf (kom_errout, "Dumma Emacs! Fattar du inte att du inte ska "
		 "bryta en\nrad inuti en str{ng bara f|r att man anv{nder "
		 "} och {???\n");
	break;

    case  KOM_SERVER_IS_CRAZY:
	fprintf (kom_errout, "Hmm, jag tror servern har b|rjat tala i "
		 "tungom}l...\n");
	break;

    case  KOM_CLIENT_IS_CRAZY:
	fprintf (kom_errout, "Hoppschan. Jag har vischt b|rjat schluddra.\n");
	break;
	
#ifndef COMPILE_CHECKS
    default:
	fprintf(kom_errout, "Unknown error %d\n", kom_errno);
	break;
#endif
    }
}
